akill(1)

akill - terminate a process or array session

As shipped in IRIX 6.5.30. Last changed in IRIX 6.5.30.

NAME
     akill - terminate a process or array session

SYNOPSIS
     akill [options...] [-signal] [-ash] [ASH]
     akill [options...] [-signal] -pid [PID]

DESCRIPTION
     The akill command sends a signal to the processes in the array session
     specified by the array session handle ASH, or to the single process
     specified by process ID PID.  The value of signal may be numeric or
     symbolic (see signal(5)).  The symbolic name is the name as is appears in
     /usr/include/sys/signal.h, with the SIG prefix stripped off.  Signal 15
     (SIGTERM) is sent by default; this will normally kill processes that do
     not catch or ignore the signal.

     The processes that are to be signalled by akill do not necessarily have
     to reside on the same system as the one from which the akill command is
     issued.  If array services is installed then a request to kill an array
     session will be forwarded to all of the machines in the array specified
     by the -a option (or the default array is -a was not specified).
     Similarly, a signal can be sent to an individual process on another
     machine that is running array services by using the -m and -pid options.

     akill takes several options:

     -a arrayname or -array arrayname
          Specifies the name of the array to which the command should be
          directed.  If not specified, the array services daemon's default
          destination will be used.  This option is ignored if the -pid option
          is specified.

     -ash ASH or -h ASH
          Specifies the array session handle of the array session whose
          processes are to receive the signal.  The string "-ash" itself is
          optional.  The -ash and -pid options are mutually exclusive.

     -D or -direct
          When used with -s, indicates that the request should be sent
          directly to the specified server, rather than forwarded to that
          server by the local array services daemon.  This will fail on
          systems that use array services authentication unless the -Kl and
          -Kr options are also specified.  -D is the default behavior under
          normal circumstances (but see the description of the ARRAYD_FORWARD
          variable, below).

     -F or -forward
          When used with -s, indicates that the request should be forwarded to
          the specified server via the local array services daemon, rather
          than sent directly to it.  -F is the default unless the value of the
          ARRAYD_FORWARD environment variable begins with the letter "N" (as
          in "no"; it may be in either upper or lower case).
     -Kl key or -localkey key
          Use key for the local authentication key when communicating directly
          with a remote array services daemon.  key is an unsigned 64-bit
          value.  The default local key is obtained from the environment
          variable ARRAYD_LOCALKEY; if that does not exist, no key is used.
          The actual role played by key depends on the authentication method
          used by array services in a particular configuration.  In general,
          it is not used when communicating with an array services daemon on
          the local machine.

     -Kr key or -remotekey key
          Use key for the remote authentication key when communicating
          directly with a remote array services daemon.  key is an unsigned
          64-bit value.  The default remote key is obtained from the
          environment variable ARRAYD_REMOTEKEY; if that does not exist, no
          key is used.  The actual role played by key depends on the
          authentication method used by array services in a particular
          configuration.  In general, it is not used when communicating with
          an array services daemon on the local machine.

     -l or -local
          Local request: indicates that the request should not be propagated
          to other machines (besides the machine running the array services
          daemon, if that is not the local machine).  This option is implied
          if -pid is specified.

     -L   Forces the command to be processed on the local machine only, even
          if normal array services conventions (such as the ARRAYD environment
          variable) might otherwise have caused the command to be processed by
          another machine.  If -L is specified no attempt is made to contact
          an array services daemon, so this can be useful if array services is
          not currently active.

     -m server or -machine server
          Equivalent to "-s server -l".  This is a convenient way to restrict
          the operation of akill to a single machine.

     -p port or -port port
          Specifies the port address of the array services daemon.  Defaults
          to the value of the "ARRAYD_PORT" environment variable if present,
          or the standard port number of the "sgi-arrayd" service otherwise.

     -pid PID or -i PID
          Specifies that the individual process PID, rather than all of the
          processes in an array session, should be signalled.  It is not
          generally useful for this particular operation to be performed on
          more than one machine, so the -l option is implied when -pid is
          specified.

     -s server or -server server
          Specifies the hostname or IP address of the array services daemon.
          Defaults to the value of the "ARRAYD" environment variable if
          present, or "localhost" otherwise.

     -t value or -timeout value
          Specifies the timeout value (in seconds) used for waiting on a
          single array services request.  Most commands involve one array
          services daemon requesting services from another array services
          daemon, so it will typically take two times this many seconds before
          the array command itself will timeout.  The default is 15 seconds
          (so most array commands will timeout if no response is received in
          30 seconds).

     Unless -L is specified, the array services daemon (arrayd(1M)) must be
     running on all machines that are to perform the signalling function.

SEE ALSO
     kill(1), kill(2), askillash_array(3X), askillash_local(3X),
     askillash_server(3X), askillpid_server(3X), array_services(5).